==> knox-1.2.0-src.zip: knox-1.2.0/gateway-i18n/src/main/java/org/apache/knox/gateway/i18n/messages/loggers/sout/SoutMessageLoggerFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.knox.gateway.i18n.messages.loggers.sout;

import org.apache.knox.gateway.i18n.messages.MessageLogger;
import org.apache.knox.gateway.i18n.messages.MessageLoggerFactory;

import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

public class SoutMessageLoggerFactory implements MessageLoggerFactory {

  private static SoutMessageLoggerFactory INSTANCE;
  private static final Map<String,MessageLogger> LOGGERS = new ConcurrentHashMap<>();

  public static SoutMessageLoggerFactory getFactory() {
    if( INSTANCE == null ) {
      INSTANCE = new SoutMessageLoggerFactory();
    }
    return INSTANCE;
  }

  public SoutMessageLoggerFactory() {
    INSTANCE = this;
  }

  @Override
  public MessageLogger getLogger( String name ) {
    MessageLogger logger = LOGGERS.get( name );
    if( logger == null ) {
      logger = new SoutMessageLogger( name );
      LOGGERS.put( name, logger );
    }
    return logger;
  }

}

==> knox-1.5.0-src.zip: knox-1.5.0/gateway-i18n/src/main/java/org/apache/knox/gateway/i18n/messages/loggers/sout/SoutMessageLoggerFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.knox.gateway.i18n.messages.loggers.sout;

import org.apache.knox.gateway.i18n.messages.MessageLogger;
import org.apache.knox.gateway.i18n.messages.MessageLoggerFactory;

import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

public class SoutMessageLoggerFactory implements MessageLoggerFactory {
  private static final SoutMessageLoggerFactory INSTANCE = new SoutMessageLoggerFactory();
  private static final Map<String,MessageLogger> LOGGERS = new ConcurrentHashMap<>();

  public static SoutMessageLoggerFactory getFactory() {
    return INSTANCE;
  }

  public SoutMessageLoggerFactory() {
  }

  @Override
  public MessageLogger getLogger( String name ) {
    MessageLogger logger = LOGGERS.get( name );
    if( logger == null ) {
      logger = new SoutMessageLogger();
      LOGGERS.put( name, logger );
    }
    return logger;
  }
}
